<?php
declare(strict_types = 1);
namespace app\admin\controller;

use app\common\controller\AdminBase;
use app\common\hook\ImField;
use think\facade\Cache;

class Config extends AdminBase
{
    protected $PartModel;
    protected $PartList;
    protected function initialize()
    {
        parent::initialize();
        $this->BaseModel();
        $this->BaseModel('ConfigPart','PartModel');
        $this->PartList = $this->PartModel->GetList([],false);
        if(empty($this->PartList)){
            ResClient('请先添加字段分类','0','',GetEruUrl('admin.ConfigPart.index'));
        }
        switch ($this->request->action()){
            case 'index':
                $this->getdata['fid'] = $this->getdata['fid'] ?? $this->PartList['0']['id'];
                $this->list_base['fast_url'] = GetEruUrl('admin/Config/fastedit',$this->getdata);
                $this->list_base['url'] = GetEruUrl('admin/Config/getlist',$this->getdata);
                $this->ListTable();
                break;
            case 'create':
            case 'edit':
            case 'save':
                $this->list_base['url'] = GetEruUrl('admin/Config/save',$this->getdata);
                $this->list_base['title'] = $this->request->action() == 'create' ? '添加配置字段' : '编辑配置字段';
                $this->FormFile();
                break;
        }
    }
    protected function ListTable(){
        $this->list_file = [
            ['field' => 'id','title' => 'ID','width' => '80','textalign' => 'center'],
            ['field' => 'title','title' => '配置名称','type' => $this->user_auth['edit'] ? 'edit' : 'text','width' => '30%'],
            ['field' => 'field','title' => '变量','width' => '150'],
            ['field' => 'type','title' => '表单类型','width' => '150','type' => 'radio','textalign' => 'center','list' => [
                ['value' => 'text','title' => '单行文本框'],
                ['value' => 'textarea','title' => '多行文本框'],
                ['value' => 'radio','title' => '单选框'],
                ['value' => 'checkbox','title' => '多选框'],
                ['value' => 'select','title' => '下拉菜单'],
                ['value' => 'editor','title' => '富文本编辑器'],
                ['value' => 'money','title' => '金额'],
                ['value' => 'number','title' => '数字'],
                ['value' => 'datetime','title' => '日期 + 时间'],
                ['value' => 'date','title' => '日期'],
                ['value' => 'time','title' => '时间'],
                ['value' => 'image','title' => '单图片'],
                ['value' => 'images','title' => '多图片'],
                ['value' => 'file','title' => '单文件'],
                ['value' => 'files','title' => '多文件'],
                ['value' => 'hidden','title' => '隐藏域'],
                ['value' => 'icon','title' => '字体图标'],
                ['value' => 'getmodel','title' => '模块调用']
            ]],
            ['field' => 'required','title' => '是否必填','width' => '150','type' => 'radio','textalign' => 'center','list' => ['非必填','必填']],
            ['field' => 'sort','title' => '排序值','width' => '80','type' => $this->user_auth['edit'] ? 'edit' : 'text','textalign' => 'center'],
            ['field' => 'status','title' => '状态','type' => 'switch','text' => '启用|禁用','textalign' => 'center','width' => '100','pk' => 'id','default' => '1','disabled' => $this->user_auth['edit'] ? '0' : '1']
        ];

        if($this->user_auth['edit']) {
            array_push($this->list_file, ['field' => 'edit', 'title' => '编辑', 'width' => '80', 'type' => 'btn', 'textalign' => 'center','open' => true, 'class' => 'ery-text-green ery-text-f16', 'icon' => 'im-icon im-edit', 'url' => GetEruUrl('admin/Config/edit',['id' => '__id__']), 'fixed' => 'right']);
        }
        if($this->user_auth['del']) {
            array_push($this->list_file, ['field' => 'del', 'title' => '删除', 'width' => '80', 'type' => 'btn', 'event' => 'del', 'textalign' => 'center', 'class' => 'ery-text-red ery-text-f16', 'icon' => 'im-icon im-delete', 'url' => GetEruUrl('admin/Config/del',['id' => '__id__']), 'fixed' => 'right']);
        }
        if($this->user_auth['create']){
            $this->list_base['button'] = [['title' => '添加配置字段','open' => true, 'url' => GetEruUrl('admin/Config/create',$this->getdata)]];
        }
        $this->list_search = [
            'input' => [
                ['field' => 'key','title' => '关键词']
            ]
        ];
        foreach ($this->PartList as &$v){
            $v = [
                'title' => $v['title'],
                'url' => GetEruUrl('admin/Config/index',['fid' => $v['id']]),
                'default' => $this->getdata['fid'] == $v['id'] ? '1' : '0',
            ];
        }
        $this->list_nav = $this->PartList;
    }
    protected function FormFile(){
        $this->list_file = [
            ['field' => 'title','title' => '配置名称','type' => 'text','required' => true],
            ['field' => 'field','title' => '数据库字段名','type' => 'text','required' => true,'tip' => '参数只能是小写字母'],
            ['field' => 'type','title' => '表单类型','type' => 'select','text' => true,'required' => true,'list' => [
                ['title' => '单行文本框','value' => 'text'],
                ['title' => '多行文本框','value' => 'textarea'],
                ['title' => '单选框','value' => 'radio'],
                ['title' => '多选框','value' => 'checkbox'],
                ['title' => '下拉菜单','value' => 'select'],
                ['title' => '富文本编辑器','value' => 'editor'],
                ['title' => '金额','value' => 'money'],
                ['title' => '数字','value' => 'number'],
                ['title' => '日期 + 时间','value' => 'datetime'],
                ['title' => '日期','value' => 'date'],
                ['title' => '时间','value' => 'time'],
                ['title' => '单图片','value' => 'image'],
                ['title' => '多图片','value' => 'images'],
                ['title' => '单文件','value' => 'file'],
                ['title' => '多文件','value' => 'files'],
                ['title' => '隐藏域','value' => 'hidden'],
                ['title' => '字体图标','value' => 'icon'],
                ['title' => '模块调用','value' => 'getmodel'],
            ],'file_link' => ['radio' => ['list'],'checkbox' => ['list'],'select' => ['list'],'getmodel' => ['geturl','fielddata','gettype']]],
            ['field' => 'required','title' => '是否必填','type' => 'radio','list' => [
                ['title' => '必填项','value' => '1'],
                ['title' => '非必填项','value' => '0'],
            ],'default' => '0','required' => true,'file_link' => ['1' => ['required_list']]],
            ['field' => 'private','title' => '参数类型','type' => 'radio','list' => [
                ['title' => '私有参数','value' => '1'],
                ['title' => '公用参数','value' => '0'],
            ],'default' => '0','required' => true,'tip' => '私有参数不会分配至前台页面'],
            ['field' => 'required_list','title' => '验证规则','type' => 'select','text' => true,'list' => [
                ['title' => '手机验证','value' => 'phone'],
                ['title' => '邮箱验证','value' => 'email'],
                ['title' => '网址验证','value' => 'url'],
                ['title' => '数字验证','value' => 'number'],
                ['title' => '日期验证','value' => 'date'],
                ['title' => '身份证验证','value' => 'identity'],
            ]],
            ['field' => 'default','title' => '默认值','type' => 'text'],

            ['field' => 'geturl','title' => '请求地址','type' => 'text','tip' => '数据请求地址，可使用站外地址'],
            ['field' => 'fielddata','title' => '自订义变量','type' => 'text','tip' => '请根据返回值填写，title和value必不可少'],
            ['field' => 'gettype','title' => '调用类型','type' => 'radio','list' => [['title' => '单选','value' => '0'],['title' => '多选','value' => '1'],['title' => '下拉菜单','value' => '2']],'default' => '0'],

            ['field' => 'list','title' => '可选值','type' => 'textarea','tip' => '每行一个可选值'],
            ['field' => 'unit','title' => '单位','type' => 'text'],
            ['field' => 'tip','title' => '提示信息','type' => 'text'],

            ['field' => 'sort','title' => '排序值','type' => 'text','type_edit' => 'number','default' => '0'],
            ['field' => 'status','title' => '是否启用','type' => 'radio','list' => [['title' => '启用','value' => '1'],['title' => '禁用','value' => '0']],'default' => '1','required' => true],
            ['field' => 'fid','title' => 'FID','required' => true,'type' => 'hidden','default' => empty($this->getdata['fid']) ? '' : $this->getdata['fid']]
        ];
        if($this->request->action() == 'edit'){
            array_push($this->list_file,['field' => 'id','title' => 'ID','required' => true,'type' => 'hidden']);
            $this->list_file['1']['disabled'] = true;
        }
    }

    public function editconf(){
        if(empty($this->getdata['fid'])){
            ResClient('非法访问','0');
        }
        $this->list_base['url'] = GetEruUrl('admin/Config/saveconf');
        $this->list_file = $this->model->GetList(['fid' => $this->getdata['fid']],false);
        $radb = [];
        foreach ($this->list_file as $v){
            $radb[$v['field']] = $v['conf_value'];
        }
        return $this->ResAdminForm($radb);
    }
    public function saveconf(){
        $data = $this->SaveCheck();
        $fileList = array_keys($data);
        $fileList = $this->model->GetList(['field' => $fileList],false);
        $_m = new ImField();
        $fileList = $_m->EditForm($fileList);
        //  处理数据
        $_old = [];
        foreach ($data as $k => $v){
            foreach ($fileList as $k1 => $v1){
                if($k == $v1['field']){
                    $_old[$k] = $v1['conf_value'];
                }
            }
        }
        $data = $_m->SetForm($fileList,$data,$_old,'webdb');
        if($data['code'] == '0'){
            ResJson('',$data['msg'],$data['code']);
        }
        $update = [];
        foreach ($data['data'] as $k => $v){
            $_v = DelFile($fileList,'field',$k);
            $_v = [
                'id' => $_v['0']['id'],
                'conf_value' => $v,
            ];
            array_push($update,$_v);
        }
        if(!$this->model->saveAll($update)){
            ResJson('','保存失败','0');
        }
        Cache::delete('webdb');
        ResJson('','保存成功');
    }

    public function edithomelabel(){
        if(!empty(cookie('__LABEL__'))){
            $this->request->LABEL = '';
            cookie("__LABEL__",null);
            ResJson('','退出标签管理');
        }else{
            $this->request->LABEL = 'edit';
            cookie("__LABEL__",'editvalue',86400);
            ResJson('','进入标签管理');
        }
    }
}