<?php
declare(strict_types = 1);
namespace app\common\controller;

use think\App;
use think\exception\HttpResponseException;
use think\facade\{Cookie, Event, Route, View};
use think\Response;

abstract class Base
{
    /**
     * Request实例
     * @var \think\Request
     */
    protected $request;
    /**
     * 应用实例
     * @var \think\App
     */
    protected $app;
    /**
     * 构造方法
     * @access public
     * @param  App  $app  应用对象
     */
    public function __construct(App $app)
    {
        $this->app     = $app;
        $this->request = $this->app->request;
        // 控制器初始化
        $this->initialize();
    }
    /**
     * 网站配置
     * @var
     */
    protected $webdb;
    protected $WebPublic;
    /**
     * 用户信息
     * @var
     */
    protected $ImUser;
    /**
     * 获取请求数据
     * @var array
     */
    protected $getdata;
    protected $space_name = 'home';
    //  定义是否获取数据
    protected $ModelGetList = false;
    /**
     * 加载模板文件
     */
    protected $list_base;
    // 初始化文件
    protected function initialize(){
        if(!is_file(base_path().'app.lock') && app('http')->getName() != 'install'){
            Redirect(url('/install/index')->build());
        }else if(app('http')->getName() != 'install'){
            if(is_dir(base_path('install'))){
                DelDir(base_path('install'));
            }
            if(is_dir(public_path('home/install'))){
                DelDir('public/home/install');
            }
            $this->webdb = GetWebDb();
            $this->WebPublic = GetServer($this->webdb['public'],false);
            $this->webdb = GetServer($this->webdb);
        }
        //  标准化访问参数
        $this->list_base = [
            'base_part' => '',
            'template' => '',
            'page' => true,
        ];

        $this->ImUser = $this->request->ImUser;
        $this->getdata = DataTrim($this->request->param());
        $this->getdata = DelNull($this->getdata);
        unset($this->getdata['controller']);
        View::assign(['imuser' => $this->ImUser,'getdata' => $this->getdata,'webdb' => $this->WebPublic]);
    }
    //  设置模板信息
    protected function SetView($data = []){
        $viewconf = config('view');
        $viewconf = array_merge($viewconf,$data);
        //  定义模型目录
        $viewconf['tpl_replace_string']['__MOD__'] = "/public/{$viewconf['app']}/{$viewconf['default_dir']}/images";
        $viewconf['view_path'] = is_dir("public/{$viewconf['app']}/{$viewconf['default_dir']}/template") ? "public/{$viewconf['app']}/{$viewconf['default_dir']}/template/" : "{$viewconf['view_path']}/default/template/";
        $viewconf['cache_path'] ="{$viewconf['cache_path']}/{$viewconf['app']}/";
        config($viewconf,'view');
        return $viewconf;
    }
    //  获取模板信息
    protected function GetViewFile($template = ''){
        $options = config('view');
        $template = implode('/',explode(':', $template));
        //  获取路径
        $path = public_path("{$this->request->viewconf['app']}/{$this->request->viewconf['default_dir']}/template");
        //  拼接模板地址
        $_template = basename($template);
        $_template = explode('.',$_template);
        $_template = end($_template);

        $res = $_template == $options['view_suffix'] ? "{$path}{$template}" : "{$path}{$template}.{$options['view_suffix']}";
        if(!is_file($res)){
            $path = public_path("{$this->request->viewconf['app']}/{$options['default_dir']}/template");
            $res = $_template == $options['view_suffix'] ? "{$path}{$template}" : "{$path}{$template}.{$options['view_suffix']}";
        }
        return ['code' => !is_file($res) ? '0' : '1','template' => $res];
    }
    /**
     * 定义模型
     * @param $modelName 模型名称
     * @param $name 指定变量名称
     * @param $model 所属模块
     * @return void
     */
    protected $model;
    protected function BaseModel($modelName = '',$name = 'model',$model = ''){
        $_model = empty($model) ? "app\\common\\model" : 'app\\' . $model ."\\model";
        if(empty($modelName)){
            $modelName = $this->request->controller();
        }
        $m = $_model .'\\'. $modelName;
        $this->$name = new $m;
    }
    /**
     * 定义验证规则
     * @param string $validateName 验证器名称
     * @param string $validir   验证器路径
     */
    protected $validate;
    protected function BaseValidate($validateName = '',$validir = ''){
        $validir = empty($validir) ? 'app\common\validate' : 'app\\' . $validir .'\validate';
        if(empty($validateName)){
            $validateName = $this->request->controller();
        }
        $validateName = $validir . '\\' . $validateName;
        $this->validate = new $validateName;
    }
    // 检测权限
    protected $user_auth = [
        'index' => false,
        'read' => false,
        'create' => false,
        'edit' => false,
        'del' => false,
    ];
    protected function CheckAuth($data,$model = '',$cname = ''){
        if(empty($cname)){
            $cname = $this->request->controller();
        }
        if(empty($this->ImUser)){
            return [];
        }
        $res = Event::trigger('Auth',['type' => 'CheckAuth','data' => ['fid' => $this->ImUser['u_groupid'],'model' => $model ?: $this->space_name,'check' => $data,'cname' => $cname ?: $this->request->controller()]]);
        $this->user_auth = $res['0'];
        return $res['0'];
    }
    //  分配TDK
    protected function EditTdk($data = []){
        $this->WebPublic['web_title'] = empty($data['title']) ? $this->WebPublic['web_title'] : "{$data['title']}_{$this->WebPublic['web_title']}";
        $this->WebPublic['web_keywords'] = $data['keywords'] ?? $this->WebPublic['web_keywords'];
        $this->WebPublic['web_description'] = $data['description'] ?? $this->WebPublic['web_description'];
        View::assign(['webdb' => $this->WebPublic]);
    }
    //  检测是否登录
    protected function IsLogin(){
        return !empty($this->ImUser);
    }
}