<?php
declare(strict_types = 1);
namespace app\common\model;

use think\facade\Cache;
use think\facade\Db;

class SqlManage
{
    protected $DbName;
    protected $DbPre;
    public function __construct(){
        $database = config('database');
        $this->DbName = $database['connections'][$database['default']]['database'];
        $this->DbPre = $database['connections'][$database['default']]['prefix'];
    }
    public function GetList($data = [],$pages = true){
        $page = empty($data['page']) ? '1' : $data['page'];
        $limit = empty($data['limit']) ? '20' : $data['limit'];
        $name = empty($data['table_name']) ? "{$this->DbPre}%" : $data['table_name'];
        $query = Db::query("SHOW TABLE STATUS FROM {$this->DbName} LIKE '{$name}'");
        if($pages){
            $total = count($query);
            $query = array_slice($query,($page - 1) * $limit, (int) $limit);
        }

        foreach ($query as $k => $v){
            $_v = [
                'title' => $v['Comment'],
                'table_name' => $v['Name'],
                'limit' => $v['Rows'],
                'type' => $v['Engine'],
                'collation' => $v['Collation'],
                'data_size' => CountSize($v['Data_length']),
            ];
            $query[$k] = $_v;
        }

        $res = $pages ? [
            'total' => $total,
            'per_page' => $limit,
            'current_page' => $page,
            'last_page' => ceil($total / $limit),
            'data' => $query
        ] : $query;
        return $res;
    }
    //  还原数据表
    public function RevertSql($sql){
        try {
            $sql = str_replace("\'0\'",'0',$sql);
            $sql = str_replace("''",'null',$sql);
            Db::execute($sql);
        } catch(\Exception $e) {
            return false;
        }
        return true;
    }
    //  修复数据表
    public function Repair($tablename){
        Db::query("OPTIMIZE TABLE `{$tablename}`");
        return true;
    }
    //  备份数据表结构
    public function Backup($tablename){
        $res = '';
        $_res = Db::query("SHOW CREATE TABLE `{$tablename}`");
        $res .= "DROP TABLE IF EXISTS {$tablename};\n";
        $res .= preg_replace("/ AUTO_INCREMENT=([0-9a-z]+)/is",'',$_res['0']['Create Table']) . ";\n\n";
        return $res;
    }
    public function GetDataList($tablename,$limit,$page){
        $limit = [
            'list_rows' => $limit,
            'page' => $page,
        ];
        $_res = Db::table($tablename)->paginate($limit);
        $_res = JobArray($_res);

        foreach ($_res['data'] as $k => $v){
            $_v = "";
            foreach ($v as $k1 => $v1){
                $_v .= "'" . addslashes((string) $v1) . "',";
            }
            $_v .= ")";
            $_v = str_replace(",)","",$_v);
            $_res['data'][$k] = "INSERT INTO `{$tablename}` VALUES ({$_v});\n";
        }

        return $_res;
    }
    //  写入SQL备份文件
    public function SetFile($Sql){
        if(Cache::has('backuplist')){
            $_table = Cache::get('backuplist');
        }
        //  检测文件夹是否存在
        if(empty($_table['dir'])){
            $_table['dir'] = 'backup/sql/' . date('Y-m-d') . '.' . GetNonceStr(4);
        }
        if(!file_exists(public_path($_table['dir']))) {
            @mkdir(public_path($_table['dir']),0777,true);
        }
        //  检测文件是否存在
        if(empty($_table['files'])){
            $_table['files'] = ['0'];
        }
        Cache::set('backuplist',$_table,3600);

        $setfile = end($_table['files']);
        $setfilename = end($_table['files']) . '.sql';
        //  开始写入文件
        $res = WriteFile(public_path($_table['dir']) . '/' . $setfilename,$Sql,'a+');

        if(empty($res['code'])){
            return $res;
        }
        //  检测文件大小
        $this->CheckFileSize(public_path($_table['dir']) . '/' . $setfilename,$setfile, 1024 * 1024 * 5);

        return ['code' => '1','msg' => '写入成功'];
    }
    protected function CheckFileSize($files,$setfile,$size){
        if(@filesize($files) < ($size + 10 * 1024)) {
            return $setfile;
        }
        copy($files,"{$files}.im");
        $filePre = str_replace(basename($files),"",$files);
        $_files = GetReadFile("{$files}.im");
        $_files = explode("\n",$_files);

        $_table = Cache::get('backuplist');
        $_table = is_array($_table) ? $_table : get_object_vars($_table);

        $_newset = '';
        foreach($_files as $k => $v){
            $_newset .= "$v\n";
            if(strlen($_newset) > $size){
                WriteFile("{$filePre}/{$setfile}.sql",$_newset);
                $setfile = $setfile + 1;
                array_push($_table['files'],$setfile);
                $_newset = '';
            }
        }
        $_table['files'] = array_unique($_table['files']);
        Cache::set('backuplist',$_table,3600);

        if($_newset){
            WriteFile("{$filePre}/{$setfile}.sql",$_newset);
        }
        @unlink("{$files}.im");

        return $setfile;
    }
    //  新建数据表
    public function CreateTable($data){
        //  数据表名
        $table_name = $this->DbPre . $data['table_name'];
        $table_comment = $data['comment'] ?? '';
        $query = Db::query("SHOW TABLES LIKE '{$table_name}'");
        if(!empty($query)){
            return false;
        }
        $query = "CREATE TABLE IF NOT EXISTS `{$table_name}` (
    {$data['sql_field']},
    PRIMARY KEY  (`{$data['pk']}`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='{$table_comment}表' AUTO_INCREMENT=1;";
        try {
            Db::execute($query);
        } catch(\Exception $e) {
            return false;
        }
        return true;
    }
    //  新增数据表字段
    public function CreateField($data){
        $table_name = $this->DbPre . $data['table_name'];
        $sql = "ALTER TABLE `{$table_name}` ADD {$data['sql_field']};";
        try {
            Db::execute($sql);
        } catch(\Exception $e) {
            return false;
        }
        return true;
    }
    //  新增数据
    public function CreateData($data){
        foreach ($data['data'] as $v){
            Db::name($data['table_name'])->strict(false)->insert($v);
        }
        return true;
    }
    //  生成字段名
    public function EditCreateVal($data){
        switch ($data['sqlvalue']){
            case 'varchar':
                $sqlvalue = "varchar(255)";
                break;
            case 'int':
                $sqlvalue = "int(11)";
                break;
            case 'bigint':
                $sqlvalue = "bigint(20)";
                break;
            case 'tinyint':
                $sqlvalue = "tinyint(2)";
                break;
            case 'decimal':
                $sqlvalue = "decimal(32,2) unsigned";
                break;
            default:
                $sqlvalue = $data['sqlvalue'];
                break;
        }
        if(isset($data['default'])){
            $data['default'] = $data['default'] == '' ? '0' : $data['default'];
            $sqlvalue .= " NOT NULL DEFAULT '{$data['default']}'";
        } else {
            $sqlvalue .= " DEFAULT NULL";
        }
        if(!empty($data['inc'])){
            $sqlvalue .= " AUTO_INCREMENT";
        }

        $data['comment'] = $data['comment'] ?? '';
        $res = "`{$data['field']}` {$sqlvalue} COMMENT '{$data['comment']}'";
        return $res;
    }
}