<?php
declare(strict_types = 1);

namespace app\common\validate;

use think\Validate;

class User extends Validate
{
    protected $rule =   [
        'uid|用户ID'  => 'require|number',
        'u_name|用户名'  => 'require|unique:user|alphaDash|min:5|max:80',
        'u_password|密码'  => 'require|min:6|max:50',
        'ru_password|重复密码'  => 'require|confirm:u_password',
        'u_phone|手机'  => 'mobile',
        'u_groupid|角色'  => 'require',
        'status|启用状态'  => 'require|number|in:0,1,2',

        'name|姓名' => 'require|min:2',
        'card_no|身份证号' => 'require|idCard|unique:user_card',
        'sex|性别' => 'require|number|in:0,1,2',
    ];

    protected $message = [
        'u_name.unique' => '用户名已存在',
        'u_name.alphaDash' => '用户名只能是字母和数字',
        'u_name.min' => '用户名不得低于5位',
        'u_name.max' => '用户名不得大于80位',
    ];

    public function sceneAdminadd(){
        return $this->only(['u_name','u_phone','u_password','u_groupid','status']);
    }
    public function sceneAdminedit(){
        return $this->only(['u_name','u_phone','u_password','u_groupid','status','uid'])
            ->remove('u_password','require');
    }
    public function sceneAdminlogin(){
        return $this->only(['u_name','u_password'])->remove('u_name','unique');
    }
    //  前台登录，用户名和密码二选一，如果用户名存在，则必须验证密码
    public function sceneHomelogin(){
        return $this->only(['u_name','u_phone','u_password'])
            ->remove('u_name',true)->remove('u_phone',true)->remove('u_password',true)
            ->append('u_phone','requireWithout:u_name')->append('u_name','requireWithout:u_phone')
            ->append('u_password','requireWith:u_name');
    }
    //  前台注册，用户名和密码二选一，如果用户名存在，则必须验证密码
    public function sceneHomereg(){
        return $this->only(['u_name','u_phone','u_password','ru_password','web_user_cont'])
            ->remove('u_name','require')->remove('u_phone','require')
            ->append('u_name','requireWithout:u_phone')
            ->append('u_phone','requireWithout:u_name');
    }
    //  密码找回，用户名和密码二选一，如果用户名存在，则必须验证密码
    public function sceneRepwd(){
        return $this->only(['u_phone','u_password','ru_password']);
    }
}